SolanaUtils class
Utility class for Solana-related operations that don't require a client instance
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deriveKeypairFromMnemonic(
String mnemonic, int account, int change) → Future< Ed25519HDKeyPair> - Derives a Solana keypair from a mnemonic seed phrase
-
generateMnemonic(
) → Future< String> - Generates a new 12-word mnemonic seed phrase